import { ObjectMap, Token, Type } from '@ts-ioc/core';
import { IConfiguration, CorsOptions, ModelOptions } from './IConfiguration';
import { LogConfigure } from '@ts-ioc/logs';
/**
 * mvc configuration
 *
 * @export
 * @interface Configuration
 */
export declare class Configuration implements IConfiguration {
    constructor();
    assertUrlRegExp: RegExp;
    routeUrlRegExp: any;
    isRouteUrl?(ctxUrl: string): boolean;
    /**
     * hostname.
     *
     * @memberof Configuration
     */
    hostname: string;
    /**
     * port
     *
     * @memberof Configuration
     */
    port: number;
    /**
     * system file root directory.
     */
    rootdir: string;
    session: {
        key: string;
        maxAge: number;
        overwrite: boolean;
        httpOnly: boolean;
        signed: boolean;
        rolling: boolean;
    };
    /**
     * contents path of files, static files. default in 'public'
     *
     * @type {(string | string[])}
     * @memberof Configuration
     */
    contents?: string[];
    /**
     * web site base url path. route prefix.
     *
     * @type {string}
     * @memberOf Configuration
     */
    routePrefix: string;
    /**
     * custom config key value setting.
     *
     * @type {IMap<any>}
     * @memberOf Configuration
     */
    setting?: ObjectMap<any>;
    /**
     * custom config connections.
     *
     * @type {ObjectMap<any>}
     * @memberof Configuration
     */
    connections?: ObjectMap<any>;
    /**
     * some middleware befor router middleware to deal with http request.
     *
     * @type {Token<any>[]}
     * @memberof Configuration
     */
    beforeMiddlewares?: Token<any>[];
    /**
     * the router middleware.
     *
     * @type {Token<any>}
     * @memberof Configuration
     */
    routerMiddlewate?: Token<any>;
    /**
     * custom middleware match path, './middlewares/\*\*\/*{.js,.ts}', '!.\/**\/*.d.ts\' in your project.
     */
    middlewares?: string | string[];
    /**
     * some middleware after router middleware to deal with http request.
     *
     * @type {Token<any>[]}
     * @memberof Configuration
     */
    afterMiddlewares?: Token<any>[];
    /**
     * exclude some middlewares
     *
     * @type {Token<any>[]}
     * @memberof Configuration
     */
    excludeMiddlewares?: Token<any>[];
    /**
     * use middlewars. if not config will load all.
     *
     * @type {Token<any>[]}
     * @memberof Configuration
     */
    useMiddlewares?: Token<any>[];
    /**
     * used server Middlewares
     *
     * @type {Token<any>[]}
     * @memberof Configuration
     */
    usedServerMiddlewares?: Token<any>[];
    /**
     * controllers match. default `./controllers/\*\*\/*{.js,.ts}`, '!.\/**\/*.d.ts\' in your project..
     *
     * @type {(string | string[])}
     * @memberOf Configuration
     */
    controllers?: string | string[];
    /**
     * use controllers. if not config will load all.
     *
     * @type {Token<any>[]}
     * @memberof Configuration
     */
    useControllers?: Token<any>[];
    /**
     * global cors default options.
     *
     * @type {CorsOptions}
     * @memberof Configuration
     */
    corsOptions?: CorsOptions;
    /**
     * custom aop services. default './aop/\*\*\/*{.js,.ts}', '!.\/**\/*.d.ts\'
     *
     * @type {(string | string[])}
     * @memberof Configuration
     */
    aop?: string | string[];
    /**
     * used aop
     *
     * @type {Token<any>[]}
     * @memberof Configuration
     */
    usedAops?: Token<any>[];
    /**
     * views folder, default `./views` in your project.
     *
     * @memberof Configuration
     */
    views: string;
    /**
     * render view options.
     *
     * @memberof Configuration
     */
    viewsOptions: {
        extension: string;
        map: {
            html: string;
        };
    };
    modelOptions?: ModelOptions;
    /**
     * in debug log. defult false.
     *
     * @memberof Configuration
     */
    debug: boolean;
    logConfig?: LogConfigure | Type<LogConfigure>;
    static classAnnations: any;
}
